#include <ncurses.h>
#include <iostream>
#include <stdlib.h>
#include <unistd.h>
#include "StdPijo.h"
#include "ranking.h"
#include "challenges.h"
#include "tablero.h"
#include "menu.h"
#include "portada.h"

using namespace std;
using namespace STDP;

int main()
{
	srand(time(NULL));
	
	system("clear");
	
	string jugador;
	
	cout << "Introduce tu nombre para el Ranking: ";
	getline(cin, jugador);
	
	StdPijo& stdp = StdPijo::p();
	
	stdp.init();
	stdp.clearScreen();
	stdp.setGlobalEscapeDelay(0);
	
	Tablero tablero(30,10);
	tablero.setJugador(jugador);
	Portada portada;
	Menu menu;
	Ranking ranking;
	Challenges challenges;
	
	int estado = -1;
	
	stdp.refreshScr();
	
	while(estado != ESALIR)
	{
		switch(estado)
		{
			case EPORTADA:
				estado = portada.ejecutar();
				stdp.clearScreen();
				portada.mostrar();
				stdp.refreshScr();
				usleep(100000);
				break;
			case EMENU:
				estado = menu.ejecutar();
				menu.mostrar();
				if(estado == EJUEGO)
					tablero.reiniciar(true);
				if(estado != EMENU)
					erase();
				stdp.refreshScr();
				break;
			case EJUEGO:
				estado = tablero.ejecutar(ranking,challenges);
				tablero.mostrar();
				stdp.refreshScr();
				break;
			case ERANKING:
				estado = ranking.ejecutar();
				ranking.mostrar();
				stdp.refreshScr();
				break;
			case ECHALLENGES:
				estado = challenges.ejecutar();
				challenges.mostrar();
				stdp.refreshScr();
				break;
			case EPERDIDO:
				estado = EMENU;
				tablero.setNivel(1);
				break;
			case EVICTORIA:
				tablero.setNivel(tablero.getNivel()+1);
				tablero.reiniciar(false);
				estado = EJUEGO;
				break;
		}
	}
	
	stdp.end();
	
	system("clear");
	
	return 0;
	/*        
	initscr();

        printw("Upper left corner           "); addch(ACS_ULCORNER); printw("\n"); 
        printw("Lower left corner           "); addch(ACS_LLCORNER); printw("\n");
        printw("Lower right corner          "); addch(ACS_LRCORNER); printw("\n");
        printw("Tee pointing right          "); addch(ACS_LTEE); printw("\n");
        printw("Tee pointing left           "); addch(ACS_RTEE); printw("\n");
        printw("Tee pointing up             "); addch(ACS_BTEE); printw("\n");
        printw("Tee pointing down           "); addch(ACS_TTEE); printw("\n");
        printw("Horizontal line             "); addch(ACS_HLINE); printw("\n");
        printw("Vertical line               "); addch(ACS_VLINE); printw("\n");
        printw("Large Plus or cross over    "); addch(ACS_PLUS); printw("\n");
        printw("Scan Line 1                 "); addch(ACS_S1); printw("\n");
        printw("Scan Line 3                 "); addch(ACS_S3); printw("\n");
        printw("Scan Line 7                 "); addch(ACS_S7); printw("\n");
        printw("Scan Line 9                 "); addch(ACS_S9); printw("\n");
        printw("Diamond                     "); addch(ACS_DIAMOND); printw("\n");
        printw("Checker board (stipple)     "); addch(ACS_CKBOARD); printw("\n");
        printw("Degree Symbol               "); addch(ACS_DEGREE); printw("\n");
        printw("Plus/Minus Symbol           "); addch(ACS_PLMINUS); printw("\n");
        printw("Bullet                      "); addch(ACS_BULLET); printw("\n");
        printw("Arrow Pointing Left         "); addch(ACS_LARROW); printw("\n");
        printw("Arrow Pointing Right        "); addch(ACS_RARROW); printw("\n");
        printw("Arrow Pointing Down         "); addch(ACS_DARROW); printw("\n");
        printw("Arrow Pointing Up           "); addch(ACS_UARROW); printw("\n");
        printw("Board of squares            "); addch(ACS_BOARD); printw("\n");
        printw("Lantern Symbol              "); addch(ACS_LANTERN); printw("\n");
        printw("Solid Square Block          "); addch(ACS_BLOCK); printw("\n");
        printw("Less/Equal sign             "); addch(ACS_LEQUAL); printw("\n");
        printw("Greater/Equal sign          "); addch(ACS_GEQUAL); printw("\n");
        printw("Pi                          "); addch(ACS_PI); printw("\n");
        printw("Not equal                   "); addch(ACS_NEQUAL); printw("\n");
        printw("UK pound sign               "); addch(ACS_STERLING); printw("\n");
	
        refresh();
        getch();
        endwin();

	return 0;*/
}

